summaryrefslogtreecommitdiffstats
path: root/kipi-plugins/gpssync/kmlgpsdataparser.h
diff options
context:
space:
mode:
Diffstat (limited to 'kipi-plugins/gpssync/kmlgpsdataparser.h')
-rw-r--r--kipi-plugins/gpssync/kmlgpsdataparser.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kipi-plugins/gpssync/kmlgpsdataparser.h b/kipi-plugins/gpssync/kmlgpsdataparser.h
index b570274..fb760dd 100644
--- a/kipi-plugins/gpssync/kmlgpsdataparser.h
+++ b/kipi-plugins/gpssync/kmlgpsdataparser.h
@@ -50,19 +50,19 @@ public:
*/
TQString lineString();
/*! Create a KML Element that will contain the linetrace of the GPS
* @param tqparent the TQDomElement to which the track will be added
* @param root the TQDomDocument used to create all elements
* @param altitudeMode altitude mode of the line and points
*/
- void CreateTrackLine(TQDomElement &tqparent, TQDomDocument &root, int altitudeMode);
+ void CreateTrackLine(TQDomElement &parent, TQDomDocument &root, int altitudeMode);
/*! Create a KML Element that will contain the points and of the GPS
* @param tqparent the TQDomElement to which the track will be added
* @param root the TQDomDocument used to create all elements
* @param timeZone the Timezone of the pictures
* @param altitudeMode altitude mode of the line and points
*/
- void CreateTrackPoints(TQDomElement &tqparent, TQDomDocument &root, int timeZone, int altitudeMode);
+ void CreateTrackPoints(TQDomElement &parent, TQDomDocument &root, int timeZone, int altitudeMode);
private:
@@ -73,7 +73,7 @@ private:
/*!
\fn TQDomElement KIPIGPSSyncPlugin::KMLGPSDataParser::addKmlElement(TQDomElement target, TQString tag)
* Add a new element
* @param target the tqparent element to which add the element
* @param tag the new element name
* @return the New element
*/
@@ -87,7 +87,7 @@ private:
/*!
\fn TQDomElement KIPIGPSSyncPlugin::KMLGPSDataParser::addKmlTextElement(TQDomElement target, TQString tag, TQString text)
* Add a new element with a text
* @param target the tqparent element to which add the element
* @param tag the new element name
* @param text the text content of the new element
* @return the New element
@@ -50,19 +50,19 @@ public:
TQString lineString();
/*! Create a KML Element that will contain the linetrace of the GPS
- * @param tqparent the TQDomElement to which the track will be added
+ * @param parent the TQDomElement to which the track will be added
* @param root the TQDomDocument used to create all elements
* @param altitudeMode altitude mode of the line and points
@@ -50,19 +50,19 @@ public:
/*! Create a KML Element that will contain the points and of the GPS
- * @param tqparent the TQDomElement to which the track will be added
+ * @param parent the TQDomElement to which the track will be added
* @param root the TQDomDocument used to create all elements
* @param timeZone the Timezone of the pictures
@@ -73,7 +73,7 @@ private:
\fn TQDomElement KIPIGPSSyncPlugin::KMLGPSDataParser::addKmlElement(TQDomElement target, TQString tag)
* Add a new element
- * @param target the tqparent element to which add the element
+ * @param target the parent element to which add the element
* @param tag the new element name
* @return the New element
@@ -87,7 +87,7 @@ private:
\fn TQDomElement KIPIGPSSyncPlugin::KMLGPSDataParser::addKmlTextElement(TQDomElement target, TQString tag, TQString text)
* Add a new element with a text
- * @param target the tqparent element to which add the element
+ * @param target the parent element to which add the element
* @param tag the new element name
* @param text the text content of the new element